.sq-data-box {
    position: relative;
    width: 150px;
    height: 22px;
}

.sq-data-box .sqn-select {
    width: 100%;
}

.sq-data-box .sq-data-box-dropdown {
    position: absolute;
    top: 22px;
    left: 0;
    width: 500px;
    height: 200px;
    z-index: 150;
    background-color: #ffffff;
    border: 1px solid #c1c1c1;
    box-shadow: 0 1px 3px rgba(0, 0, 0, .12), 0 1px 2px rgba(0, 0, 0, .24);
    display: flex;
    flex-direction: row;
}

.sq-data-box-left {
    flex: 0 0 150px;
    position: relative;
}

.sq-data-box-left select {
    border: 0;
    position: absolute;
    width: 100%;
    height: 100%;
}

.sq-data-box-left select:focus {
    outline: 0;
}

.sq-data-box-left select option {
    padding-left: 11px;
}

.sq-data-box-right {
    flex: 1 1 auto;
    margin-left: 10px;
    display: flex;
    flex-direction: column;
}

.sq-data-box-right .toolbar {
    padding-left: 0;
    padding-right: 0;
    padding-top: 2px;
    flex: 0 0 auto;
}

.sq-data-box-right .toolbar label {
    font-size: 10px;
    width: auto;
}

.sq-data-box-right .toolbar .btn-group .btn {
    font-size: 10px;
    padding: 0px 3px;
    height: 20px;
}

.sq-data-box-right .recent-cloud {
    flex: 1 1 auto;
}

.sq-data-box-right .recent-cloud .jqcloud-word {
    cursor: pointer;
    font-weight: 600;
}

.sq-data-box-right .recent-cloud .jqcloud-word:hover {
    text-decoration: underline;
}

.sq-data-box-overlay {
    width: 100%;
    height: 100%;
    top: 0;
    left: 0;
    z-index: 100;
    position: fixed;
}

.sq-data-box-right .recent-cloud-title {
    flex: 0 0 auto;
    text-align: center;
}

.sq-data-box select optgroup {
    text-indent: 5px;
    background-color: #dddddd;
    font-weight: 400;
}

.sq-data-box select optgroup option {
    background-color: #ffffff;
    padding-left: 0;
}

.data-selector.sq-selector {
    width: auto;
    height: 100%;
}

.sq-data-box .pulsing-text {
    animation: pulsing-animation 2s ease infinite;
}

@keyframes pulsing-animation {
    50% {
        opacity: 0.4;
    }
}